pub struct Analyzer<'a, O: PineOutput> { /* private fields */ }Implementations
Sourceimpl<'a, O: PineOutput> Analyzer<'a, O>
impl<'a, O: PineOutput> Analyzer<'a, O>
pub fn new( builtins: &'a HashMap<String, Value<O>>, loader: Option<&'a dyn LibraryLoader>, ) -> Self
Sourcepub fn analyze(self, program: &Program) -> Vec<Diagnostic>
pub fn analyze(self, program: &Program) -> Vec<Diagnostic>
Analyze a whole program, returning the errors found.
Sourcepub fn into_analysis(self, program: &Program) -> (Vec<Diagnostic>, SymbolTable)
pub fn into_analysis(self, program: &Program) -> (Vec<Diagnostic>, SymbolTable)
Analyze a whole program, returning both the errors and the symbol table reconstructed from the same walk.